==> appslandia-common-2.4-sources.jar: com/appslandia/common/utils/ValueUtils.java <==
// The MIT License (MIT)
// Copyright © 2015 AppsLandia. All rights reserved.

// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:

// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.

// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

package com.appslandia.common.utils;

/**
 *
 * @author <a href="mailto:haducloc13@gmail.com">Loc Ha</a>
 *
 */
public class ValueUtils {

	public static int inRange(int checkValue, int min, int max) {
		if (checkValue < min) {
			return min;
		}
		if (checkValue > max) {
			return max;
		}
		return checkValue;
	}

	public static double inRange(double checkValue, double min, double max) {
		if (checkValue < min) {
			return min;
		}
		if (checkValue > max) {
			return max;
		}
		return checkValue;
	}

	public static int valueOrDefault(int checkValue, int defaultValue) {
		return (checkValue == 0) ? defaultValue : checkValue;
	}

	public static <T> T valueOrDefault(T checkValue, T defaultValue) {
		return (checkValue == null) ? defaultValue : checkValue;
	}
}

==> appslandia-common-3.2-sources.jar: com/appslandia/common/utils/ValueUtils.java <==
// The MIT License (MIT)
// Copyright © 2015 AppsLandia. All rights reserved.

// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:

// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.

// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

package com.appslandia.common.utils;

/**
 *
 * @author <a href="mailto:haducloc13@gmail.com">Loc Ha</a>
 *
 */
public class ValueUtils {

	public static int inRange(int checkValue, int min, int max) {
		if (checkValue < min) {
			return min;
		}
		if (checkValue > max) {
			return max;
		}
		return checkValue;
	}

	public static double inRange(double checkValue, double min, double max) {
		if (checkValue < min) {
			return min;
		}
		if (checkValue > max) {
			return max;
		}
		return checkValue;
	}

	public static int valueOrDefault(int checkValue, int defaultValue) {
		return (checkValue == 0) ? defaultValue : checkValue;
	}

	public static <T> T valueOrDefault(T checkValue, T defaultValue) {
		return (checkValue == null) ? defaultValue : checkValue;
	}

	public static <T> T[] nullOrNotEmpty(T[] checkValue) {
		return ((checkValue == null) || (checkValue.length > 0)) ? checkValue : null;
	}
}
